import React, {useState, useEffect, useRef, Component} from 'react'
import './App.scss'
import {Provider, connect} from 'react-redux'
import {Router, Route, Link, Redirect, Switch} from 'react-router-dom'
import createHistory from "history/createBrowserHistory"
import {
  store
} from "./reducers"
import {
  actionFullChatList
} from "./actions"

import {
  Login, 
  Register, 
  Main,
  ChatsPage,
  CMsgPage
} from "./pages"
import {
  CChatList
} from "./components"

import Grid from '@mui/material/Grid'



const PageNoChat = () => (
  <h1>Выбирай чат</h1>
)

const AuthSwitch = ({auth={}, getFirstChats}) => {

  useEffect(() => {
    const userId = auth.payload?.sub?.id 
    if (userId) {
      getFirstChats(userId, 0, 20)
    } 
  })

  return (
    <>      
      {auth.token ? 
      <>
        <Main>

          <Grid item xs={12} sm={4}>
              <ChatsPage>
                <Switch> 
                  <Route path="/find" component={PageNoChat} />
                  <Route path="*" component={CChatList} /> 
                </Switch>
              </ChatsPage>
          </Grid>

          <Grid item xs={12} sm={8}>
            <Switch> 
              <Route path="/main" component={PageNoChat} exact/>
              <Route path="/main/:_id" component={CMsgPage} />
              <Route path="*" component={PageNoChat} /> 
            </Switch>
          </Grid>

        </Main>
      </>
      : 
      <>      
        <Switch>        
          <Route path="/reg" component={Register} />
          <Route path="/login" component={Login} />
          <Route path="*" component={Login} />
        </Switch>
      </>
      }
    </>
  )
}
const CAuthSwitch = connect(state => ({auth: state.auth }), 
                                                  {getFirstChats: actionFullChatList} )(AuthSwitch)

const history = createHistory()

function App() {

  return (
    <Router history={history}>
      <Provider store={store}>
          <div className="App">
                                
            <CAuthSwitch />
          
          </div>
        </Provider>
    </Router>  
  )
}
export default App




// const RRoute = ({ action, component:Component, ...routeProps}) => {
//   const WrapperComponent = (componentProps) => {
//     action(componentProps.match)
//     return <Component {...componentProps} />
//   }
//   return <Route {...routeProps} component={WrapperComponent} />
// }
// const CRRoute = connect(null, {action: match => ({type: 'ROUTE', match})})(RRoute)


